Repl

Struct Repl 

pub struct Repl<Context, E: Display> { /* private fields */ }
Main REPL struct

Implementations

Source

impl<Context, E> Repl<Context, E>
where E: Display + From<Error>,

pub fn new(context: Context) -> Self

Create a new Repl with the given context’s initial value.

pub fn with_name(self, name: &str) -> Self

Give your Repl a name. This is used in the help summary for the Repl.

pub fn with_version(self, version: &str) -> Self

Give your Repl a version. This is used in the help summary for the Repl.

pub fn with_description(self, description: &str) -> Self

Give your Repl a description. This is used in the help summary for the Repl.

pub fn with_prompt(self, prompt: &'static dyn Display) -> Self

Give your Repl a custom prompt. The default prompt is the Repl name, followed by a >, all in green, followed by a space.

pub fn with_help_viewer<V: 'static + HelpViewer>(self, help_viewer: V) -> Self

Pass in a custom help viewer

pub fn with_error_handler( self, handler: fn(error: E, repl: &Repl<Context, E>) -> Result<()>, ) -> Self

Pass in a custom error handler. This is really only for testing - the default error handler simply prints the error to stderr and then returns

pub fn use_completion(self, value: bool) -> Self

Set whether to use command completion when tab is hit. Defaults to false.

pub fn add_command(self, command: Command<Context, E>) -> Self

Add a command to your REPL

pub fn run(&mut self) -> Result<()>